@@ -1,11 +1,12 @@
 ##----------------------------------------------------------------------------
 ## Asynchronous HTTP Request and Promise - ~/lib/HTTP/Promise/Message.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2022 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/03/21
-## Modified 2022/03/21
-## All rights reserved
+## Modified 2022/08/06
+## All rights reserved.
+## 
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
 ## under the same terms as Perl itself.
@@ -25,7 +26,7 @@ BEGIN
     our $CRLF = "\015\012";
     # HTTP/1.0, HTTP/1.1, HTTP/2
     our $HTTP_VERSION  = qr/(?<http_protocol>HTTP\/(?<http_version>(?<http_vers_major>[0-9])(?:\.(?<http_vers_minor>[0-9]))?))/;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -668,7 +669,21 @@ sub encode
     return(1);
 }
 
-sub entity { return( shift->_set_get_object_without_init( 'entity', 'HTTP::Promise::Entity', @_ ) ); }
+# sub entity { return( shift->_set_get_object_without_init( 'entity', 'HTTP::Promise::Entity', @_ ) ); }
+sub entity
+{
+    my $self = shift( @_ );
+    if( @_ )
+    {
+        return( $self->_set_get_object_without_init( 'entity', 'HTTP::Promise::Entity', @_ ) );
+    }
+    if( $self->_is_a( $self->{entity} => 'HTTP::Promise::Entity' ) &&
+        !$self->{entity}->{http_message} )
+    {
+        $self->{entity}->{http_message} = $self;
+    }
+    return( $self->_set_get_object_without_init( 'entity', 'HTTP::Promise::Entity' ) );
+}
 
 sub header { return( shift->headers->header( @_ ) ); }
 
@@ -1000,7 +1015,7 @@ sub STORABLE_thaw { CORE::return( CORE::shift->THAW( @_ ) ); }
 # NOTE: sub THAW is inherited
 sub THAW
 {
-    my( $self, undef, @args ) = @_;
+    my( $self, $serialiser, @args ) = @_;
     my $ref = ( CORE::scalar( @args ) == 1 && CORE::ref( $args[0] ) eq 'ARRAY' ) ? CORE::shift( @args ) : \@args;
     my $class = ( CORE::defined( $ref ) && CORE::ref( $ref ) eq 'ARRAY' && CORE::scalar( @$ref ) > 1 ) ? CORE::shift( @$ref ) : ( CORE::ref( $self ) || $self );
     my $hash = CORE::ref( $ref ) eq 'ARRAY' ? CORE::shift( @$ref ) : {};
@@ -1033,12 +1048,6 @@ sub THAW
     {
         $new = bless( $hash => $class );
     }
-    if( CORE::exists( $new->{entity} ) && 
-        CORE::defined( $new->{entity} ) && 
-        $new->{entity} )
-    {
-        $new->{entity}->{http_message} = $new;
-    }
     CORE::return( $new );
 }
 
@@ -1065,7 +1074,7 @@ HTTP::Promise::Message - HTTP Message Class
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
